@@ -16,7 +16,7 @@ const EXCHANGE_NAME: &str = "kucoin";
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21"; "inconclusive")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_trade,
@@ -30,7 +30,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_l2_event,
@@ -44,7 +44,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_l3_event,
@@ -58,7 +58,7 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     gen_test_snapshot_code!(
         crawl_l2_snapshot,
@@ -69,10 +69,23 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     )
 }
 
+#[test_case(MarketType::Spot)]
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+#[test_case(MarketType::InverseFuture)]
+fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
+    gen_test_snapshot_without_symbol_code!(
+        crawl_l2_snapshot,
+        EXCHANGE_NAME,
+        market_type,
+        MessageType::L2Snapshot
+    )
+}
+
 #[test_case(MarketType::Spot, "BTC-USDT"; "inconclusive")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
     gen_test_snapshot_code!(
         crawl_l3_snapshot,
@@ -86,7 +99,7 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMU21")]
+#[test_case(MarketType::InverseFuture, "XBTMZ21")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_ticker,
